API documentation
=================

cli
---
.. automodule:: mps_motion.cli
    :members:

block_matching
--------------
.. automodule:: mps_motion.block_matching
    :members:

dualtvl1
--------
.. automodule:: mps_motion.dualtvl1
    :members:

farneback
---------
.. automodule:: mps_motion.farneback
    :members:

filters
-------
.. automodule:: mps_motion.filters
    :members:

lucas_kanade
------------
.. automodule:: mps_motion.lucas_kanade
    :members:

mechanics
---------
.. automodule:: mps_motion.mechanics
    :members:

motion_tracking
---------------
.. automodule:: mps_motion.motion_tracking
    :members:

scaling
-------
.. automodule:: mps_motion.scaling
    :members:

stats
-----
.. automodule:: mps_motion.stats
    :members:

utils
-----
.. automodule:: mps_motion.utils
    :members:

visu
----
.. automodule:: mps_motion.visu
    :members:
